**pypercolate** is a scientific Python package that implements the `Newman-Ziff
algorithm`_ for Monte Carlo simulation of percolation on graphs.

|today| (Version |release|)

Andreas Sorge <pypercolate@asorge.de>

- `Max Planck Institute for Dynamics & Self-Organization <http://www.ds.mpg.de/en>`_, Göttingen, Germany
- Organization for Research on Complex Adaptive Systems, Göttingen, Germany

Citation
--------

Please cite as: Andreas Sorge. (2015). pypercolate |release|. Zenodo. |DOI|

Documentation license
---------------------

This documentation is licensed under a `Creative Commons Attribution 4.0 International License`_.

.. _Creative Commons Attribution 4.0 International License: http://creativecommons.org/licenses/by/4.0/

.. _Newman-Ziff algorithm: http://arxiv.org/abs/cond-mat/0101295

.. |DOI| image:: https://zenodo.org/badge/6089/andsor/pypercolate.svg
         :target: https://zenodo.org/badge/latestdoi/6089/andsor/pypercolate

.. |CC| image:: _static/cc-by.*
